pub fn run_install_hooks_impl() -> Result<()>
Install the canonical git hooks into the current project’s .git-hooks/.
.git-hooks/
Returns an error if filesystem access or git config invocation fails.
git config