Module gitignore

Module gitignore 

Gitignore pattern utilities.

Functions

parse_gitignore
Parse .gitignore from root and return a list of simple directory/file names to exclude during traversal.
should_skip_path
Check whether path should be skipped based on its directory components matching any entry in excludes.