Module utils

Module utils 

Shared utility functions.

Functions

find_project_root
Finds the project root by climbing up the directory tree from the CWD. Returns the current directory if no root marker is found.