pub async fn run(args: FormatArgs) -> Result<()>Expand description
Executes the format command.
Errors
Returns an error only if the argument validation fails. Per-language failures are reported on stderr and accumulate into the CLI exit code.
pub async fn run(args: FormatArgs) -> Result<()>Executes the format command.
Returns an error only if the argument validation fails. Per-language failures are reported on stderr and accumulate into the CLI exit code.