Module utils
resq_
cli
0.2.0
Module utils
Module Items
Functions
In crate resq_
cli
resq_cli
Module
utils
Shared utility functions.
Functions

find_
project_
root
Finds the project root by climbing up the directory tree from the CWD. Returns the current directory if no root marker is found.